import React from 'react';
import classnames from 'classnames';
import styles from './styles.scss';

class Navigation extends React.PureComponent {
  render() {
    let theme;
    if (this.props.theme) {
      theme = this.props.theme;
    } else if (this.props.site.toLowerCase() === 'magazine') {
      theme = 'dark';
    } else {
      theme = 'light';
    }

    return (
      <nav
        title='navigation'
        className={classnames('navigation', 'global', styles.styles)}
      >
        <div
          className={classnames({
            magazine: this.props.site.toLowerCase() === 'magazine',
            dark: theme === 'dark',
            light: theme === 'light',
          })}
          id='global-header'
        >
          <div id='header-contents'>
            <div id='global-branding'>
              {this.props.site.toLowerCase() === 'magazine' && (
                <a
                  className='navbar-brand'
                  href='https://www.politico.com/magazine/'
                  title='POLITICO'
                  target='_top'
                >
                  <span className='bt-icon bt-icon--politico' />
                  <span className='bt-icon bt-icon--magazine' />
                </a>
              )}
              {this.props.site.toLowerCase() !== 'magazine' && (
                <a
                  className='navbar-brand'
                  href='https://www.politico.com/'
                  title='POLITICO'
                  target='_top'
                >
                  <span className='bt-icon bt-icon--politico' />
                </a>
              )}
            </div>

            <nav id='nav-micro' role='home'>
              <div className='header-content'>
                <div className='header-left'>
                  <a href='https://www.politico.com'>
                    <svg
                      xmlns='http://www.w3.org/2000/svg'
                      height='20px'
                      version='1.1'
                      x='0px'
                      y='0px'
                      viewBox='0 0 100 100'
                      enableBackground='new 0 0 100 100'
                      xmlSpace='preserve'
                    >
                      <path d='M79.5,81.458h-57V41.27L51,16.729L79.5,41.27V81.458z M25.5,78.458h51V42.646L51,20.688L25.5,42.646V78.458z' />
                    </svg>
                  </a>
                </div>

                <div className='header-right'>
                  <ul className='micro-list'>
                    {this.props.site.toLowerCase() !== 'magazine' && (
                      <li className='subnav d-none d-sm-block'>
                        <a
                          href='https://www.politico.com/magazine/'
                          target='_top'
                        >
                          Mag<span className='d-sm-none d-md-none'>azine</span>
                        </a>
                      </li>
                    )}
                    <li className='subnav d-none d-sm-block'>
                      <a href='https://www.politico.com/agenda/' target='_top'>
                        <span className='d-sm-none'>The</span> Agenda
                      </a>
                    </li>
                    <li className='subnav'>
                      <a href='https://www.politicopro.com' target='_top'>
                        PRO
                      </a>
                    </li>
                  </ul>
                </div>
              </div>
            </nav>
          </div>
        </div>
      </nav>
    );
  }
}

Navigation.defaultProps = {
  site: '',
};

export default Navigation;
